# yaqd-ti

[![PyPI](https://img.shields.io/pypi/v/yaqd-ti)](https://pypi.org/project/yaqd-ti)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaqd-ti)](https://anaconda.org/conda-forge/yaqd-ti)
[![yaq](https://img.shields.io/badge/framework-yaq-orange)](https://yaq.fyi/)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)

yaq daemons for interfacing with Texas Instruments integrated circuits

This package contains the following daemon(s):

- https://yaq.fyi/daemons/ads1115